@@ -157,6 +157,7 @@ tfOnePlot <- function(x, tf=tframe(x), start=tfstart(tf), end=tfend(tf),
 	mrL <- mrR <- mr
 	mrL[4] <- 0
 	mrR[2] <- 0
+	if (YaxisR) mrR[4] <- mrR[4] + 1  # add for right labels (default is 2.1 )
 	#mn <- min(x)
     	#mn <- mn - 0.01 * abs(mn)
     	#mx <- max(x)
@@ -277,7 +278,7 @@ tfXaxis <- function (x, L1 = NULL) {
    else {
      lab1 <- rep(L1, length.out=fr * length(at2))
      # arrange for not starting in first period of year
-     s <- fr - sum(at1 < (1 + at2[1]))
+     s <- fr - sum(at1 < (1 + at2[1] - 1e-5)) # less eps because date may fail < for Jan
      if (0 < s)  lab1 <- lab1[-seqN(s)]
      lab1 <- lab1[seqN(Tobs(x))]
      }
